(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
	typeof define === 'function' && define.amd ? define(factory) :
	(global.VueInter = factory());
}(this, (function () { 'use strict';

var defaultTemplate = function (tpl, data) {
  if (!data) { return tpl }

  var re = /{(.*?)}/g;

  return tpl.replace(re, function (_, key) {
    var ret = data;

    for (var i = 0, list = key.split('.'); i < list.length; i += 1) {
      var prop = list[i];

      ret = ret ? ret[prop] : '';
    }

    return ret || ''
  })
};

function getPathSegments(path) {
  var pathArr = path.split('.');
  var parts = [];

  for (var i = 0; i < pathArr.length; i++) {
    var p = pathArr[i];

    while (p[p.length - 1] === '\\' && pathArr[i + 1] !== undefined) {
      p = p.slice(0, -1) + '.';
      p += pathArr[++i];
    }

    parts.push(p);
  }

  return parts
}

var getProp = function(data, path) {
  return getPathSegments(path).reduce(function (obj, k) { return obj && obj[k]; }, data)
};

var Vue;

var Inter = function Inter(ref) {
  var locale = ref.locale;
  var locales = ref.locales;
  var template = ref.template; if ( template === void 0 ) template = defaultTemplate;

  if ("development" === 'development' && !Vue) {
    throw new Error('You have to install `vue-inter` first: Vue.use(Inter)')
  }

  this.template = template;
  this.locales = locales;

  var silent = Vue.config.silent;
  Vue.config.silent = true;
  this.vm = new Vue({
    data: {
      $$locale: locale
    }
  });
  Vue.config.silent = silent;
};

var prototypeAccessors = { locale: {} };

Inter.install = function install (_Vue) {
  Vue = _Vue;
  Vue.mixin({
    beforeCreate: function beforeCreate() {
      this.$inter =
        this.$options.inter || (this.$parent && this.$parent.$inter);
      if (this.$inter) {
        this.$i = this.$inter.get.bind(this.$inter);
      }
    }
  });
};

prototypeAccessors.locale.get = function () {
  return this.vm._data.$$locale
};

Inter.prototype.get = function get (path) {
    var data = [], len = arguments.length - 1;
    while ( len-- > 0 ) data[ len ] = arguments[ len + 1 ];

  var localeData = this.locales[this.locale];
  if ("development" === 'development' && !localeData) {
    throw new Error(("[vue-inter] Locale \"" + (this.locale) + "\" was not found"))
  }
  var message = getProp(localeData, path);
  if ("development" === 'development' && !message) {
    throw new Error(("[vue-inter] No message under \"" + path + "\" was found"))
  }
  return (ref = this).template.apply(ref, [ message ].concat( data ))
    var ref;
};

Inter.prototype.setLocale = function setLocale (locale) {
  this.vm._data.$$locale = locale;
  return this
};

Object.defineProperties( Inter.prototype, prototypeAccessors );

return Inter;

})));
